[Mlir-commits] [mlir] [MLIR][NVVM] Shard generated operation definitions (NFC) (PR #221812)

Mehdi Amini llvmlistbot at llvm.org
Mon Sep 7 12:48:54 PDT 2026


joker-eph wrote:

FYI, some stats:

The baseline monolithic Ninja edge took 112.157s, with 111.676s of ExecuteCompiler time. Its inclusive trace totals were 40.405s frontend, 70.799s backend, 42.292s optimizer, 28.417s code generation, 15.331s function instantiation, 10.353s class instantiation, 22.391s source processing, and 10.271s class parsing.

The eight shards plus the remaining dialect TU totaled 110.072s of ExecuteCompiler time. Their inclusive totals were 72.098s frontend, 36.952s backend, 22.565s optimizer, 14.322s code generation, 17.093s function instantiation, 22.340s class instantiation, 55.510s source processing, and 42.989s class parsing. The slowest new compile edge was 14.612s.

Aggregate compiler time fell 1.4%, backend time fell 47.8%, optimizer time fell 46.6%, and code-generation time fell 49.6%. The longest compile edge fell 87.0%. Repeated work increased frontend time 78.4%, function-instantiation time 11.5%, class-instantiation time 115.8%, source-processing time 147.9%, and class-parsing time 318.6%.

The affected-target build ran 10 steps in 15.38s wall time, using 105.66s user time and 5.49s system time at 722% CPU, with 1,184,916 KiB peak RSS and zero swaps. The baseline monolithic object contained 6,342,618 text bytes; the remaining dialect object plus eight shard objects contain 6,740,626 text bytes, an increase of 6.3%. The static archive grew from 23,634,936 to 24,977,400 bytes, an increase of 5.7%.

Rebuilding mlir-opt and running six focused suites took 26.40s wall time, 367.48s user time, and 35.80s system time at 1,527% CPU, with 1,966,540 KiB peak RSS and zero swaps. The suites ran 11 tests in 0.36s, 1 in 0.08s, 6 in 0.83s, 2 in 0.22s, 1 in 0.09s, and 124 in 0.22s; all 145 tests passed.


https://github.com/llvm/llvm-project/pull/221812


More information about the Mlir-commits mailing list